Available on crate features runtime and time only.
Require a Future to complete before the specified duration has elapsed.
If the future completes before the duration has elapsed, then the completed
value is returned. Otherwise, an error is returned and the future is
cancelled.